SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = true;
SET client_min_messages = warning;
SET escape_string_warning = off;
-- PostgreSQL membership/role requiremets

CREATE TABLE Users (
        pId                                     character(36)           NOT NULL,
        Username                                character varying(255)  NOT NULL,
        ApplicationName                         character varying(255)  NOT NULL,
        Email                                   character varying(128)  NOT NULL,
        Comment                                 character varying(128)  NULL,
        Password                                character varying(255)  NOT NULL,
        PasswordQuestion                        character varying(255)  NULL,
        PasswordAnswer                          character varying(255)  NULL,
        IsApproved                              boolean                 NULL, 
        LastActivityDate                        timestamptz             NULL,
        LastLoginDate                           timestamptz             NULL,
        LastPasswordChangedDate                 timestamptz             NULL,
        CreationDate                            timestamptz             NULL, 
        IsOnLine                                boolean                 NULL,
        IsLockedOut                             boolean                 NULL,
        LastLockedOutDate                       timestamptz             NULL,
        FailedPasswordAttemptCount              integer                 NULL,
        FailedPasswordAttemptWindowStart        timestamptz             NULL,
        FailedPasswordAnswerAttemptCount        integer                 NULL,
        FailedPasswordAnswerAttemptWindowStart  timestamptz             NULL,
        CONSTRAINT users_pkey PRIMARY KEY (pId),
        CONSTRAINT users_username_application_unique UNIQUE (Username, ApplicationName)
);

CREATE INDEX users_email_index ON Users (Email);
CREATE INDEX users_islockedout_index ON Users (IsLockedOut);

CREATE TABLE Roles (
        Rolename                                character varying(255)  NOT NULL,
        ApplicationName                         character varying(255)  NOT NULL,
    CONSTRAINT roles_pkey PRIMARY KEY (Rolename, ApplicationName)
);

CREATE TABLE UsersInRoles (
        Username                                character varying(255)  NOT NULL,
        Rolename                                character varying(255)  NOT NULL,
        ApplicationName                         character varying(255)  NOT NULL,
        CONSTRAINT usersinroles_pkey PRIMARY KEY (Username, Rolename, ApplicationName),
        CONSTRAINT usersinroles_username_fkey FOREIGN KEY (Username, ApplicationName) REFERENCES Users (Username, ApplicationName) ON DELETE CASCADE,
        CONSTRAINT usersinroles_rolename_fkey FOREIGN KEY (Rolename, ApplicationName) REFERENCES Roles (Rolename, ApplicationName) ON DELETE CASCADE
);

CREATE TABLE Profiles (
        pId                                     character(36)           NOT NULL,
        Username                                character varying(255)  NOT NULL,
        ApplicationName                         character varying(255)  NOT NULL,
        IsAnonymous                             boolean                 NULL,
        LastActivityDate                        timestamptz             NULL,
        LastUpdatedDate                         timestamptz             NULL,
        CONSTRAINT profiles_pkey PRIMARY KEY (pId),
        CONSTRAINT profiles_username_application_unique UNIQUE (Username, ApplicationName),
        CONSTRAINT profiles_username_fkey FOREIGN KEY (Username, ApplicationName) REFERENCES Users (Username, ApplicationName) ON DELETE CASCADE
);

CREATE INDEX profiles_isanonymous_index ON Profiles (IsAnonymous);

CREATE TABLE ProfileData (
        pId                                     character(36)           NOT NULL,
        Profile                                 character(36)           NOT NULL,
        Name                                    character varying(255)  NOT NULL,
        ValueString                             text                    NULL,
        ValueBinary                             bytea                   NULL,
        CONSTRAINT profiledata_pkey PRIMARY KEY (pId),
        CONSTRAINT profiledata_profile_name_unique UNIQUE (Profile, Name),
        CONSTRAINT profiledata_profile_fkey FOREIGN KEY (Profile) REFERENCES Profiles (pId) ON DELETE CASCADE
);

-- ported from upstream

CREATE TABLE Albums (
	albumid serial NOT NULL ,
	title varchar (50) NOT NULL ,
	parentid int NOT NULL ,
	private boolean NULL ,
	description varchar (500) NULL ,
	ownerid text NOT NULL
);

CREATE TABLE Announcements (
	id serial NOT NULL ,
	itemdate timestamptz NOT NULL ,
	title varchar (500) NOT NULL ,
	description varchar (500) NULL ,
	staticURL varchar (500) NULL ,
	photo int NOT NULL ,
	albumid int NULL 
);

CREATE TABLE Events (
	id serial NOT NULL ,
	starttime timestamptz NOT NULL ,
	endtime timestamptz NULL ,
	title varchar (500) NOT NULL ,
	description varchar (800) NULL ,
	staticURL varchar (500) NULL ,
	location int NULL ,
	photo int NOT NULL ,
	album int NULL 
);

CREATE TABLE Locations (
	id serial NOT NULL ,
	title varchar (500) NOT NULL ,
	description varchar (800) NULL ,
	linkURL varchar (500) NULL ,
	photo int NOT NULL ,
	directions varchar (800) NULL ,
	address varchar (300) NULL 
);

CREATE TABLE MemberInfo (
	address varchar (500) NULL ,
	phone varchar (50) NULL ,
	firstname varchar (50) NULL ,
	lastname varchar (50) NULL ,
	avatar bytea NULL ,
	memberid text NOT NULL
);

CREATE TABLE images (
	id serial NOT NULL ,
	title varchar (50) NULL ,
	largeimage bytea NOT NULL ,
	thumbimage bytea NULL ,
	origimage bytea NULL ,
	album int NOT NULL ,
	notes varchar (500) NULL 
);

ALTER TABLE Albums ADD 
	CONSTRAINT PK_Albums PRIMARY KEY   
	(
		albumid
	)   
;

ALTER TABLE MemberInfo ADD 
	CONSTRAINT PK_MemberInfo PRIMARY KEY   
	(
		memberid
	)   
;


CREATE FUNCTION AlbumList (puserid text) RETURNS SETOF Albums AS $$
DECLARE
	r RECORD;
BEGIN
FOR r IN SELECT     Albums.albumid, Albums.title, Albums.private, MIN(images.id) AS DisplayImage, COUNT(images.id) AS ImageCount, Albums.description
FROM         Albums LEFT OUTER JOIN
                      images ON Albums.albumid = images.album
WHERE     (Albums.private = FALSE) OR
                     (Albums.ownerid = puserid)
GROUP BY Albums.albumid, Albums.title, Albums.private, Albums.description LOOP
      RETURN NEXT r;
END LOOP;

RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE TYPE ResultsTemp AS (letter char(1), num int);
CREATE FUNCTION MemberCountByLetter() RETURNS SETOF ResultsTemp AS $$
DECLARE 
	pletter char(1);
	pindex int;
	pmax int;
	r RECORD;
BEGIN
	pindex := ASCII('A');
	pmax := ASCII('Z');

	WHILE pindex <= pmax LOOP
		pletter := CHR(pindex);
		FOR r IN SELECT pletter AS letter,CAST(count(*) AS int) AS num FROM MemberInfo WHERE SUBSTR(lastname,1,1)=pletter LOOP
		    RETURN NEXT r;
		END LOOP;
		pindex = pindex + 1;
	END LOOP;
	
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION NextAnnouncement (pid int) RETURNS SETOF Announcements AS $$
DECLARE 
	pcurr timestamptz;
	r RECORD;
BEGIN
	SELECT itemdate FROM Announcements INTO pcurr WHERE (id = pid);

	FOR r IN SELECT nextid=id
	FROM	Announcements
	WHERE	(itemdate > pcurr OR
			(itemdate = pcurr) AND (id > pid)) ORDER BY itemdate ASC, id ASC LIMIT 1 LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION NextPrevAnnouncement (pid int, OUT pprevid int, OUT pnextid int) AS $$
DECLARE 
	pcurr timestamptz;
BEGIN
	SELECT itemdate
	FROM Announcements INTO pcurr
	WHERE (id = pid);

	SELECT	id
	FROM	Announcements INTO pprevid
	WHERE	(itemdate < pcurr OR
			(itemdate = pcurr) AND (id < pid)) ORDER BY itemdate ASC, id ASC;


	SELECT	 id
	FROM	Announcements INTO pnextid
	WHERE	(itemdate > pcurr OR
			(itemdate = pcurr) AND (id > pid)) ORDER BY itemdate DESC, id  DESC;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION NextPrevEvent (pid int,	OUT pprevid int, OUT pnextid int) AS $$
DECLARE 
	pcurr timestamptz;
BEGIN
	SELECT starttime
	FROM Events AS Events_1 INTO pcurr
	WHERE (id = pid);

	SELECT	id
	FROM	Events INTO pprevid
	WHERE	(starttime < pcurr OR
			(starttime = pcurr) AND (id < pid)) ORDER BY starttime ASC, id ASC;

	SELECT	 id
	FROM	Events INTO pnextid
	WHERE	(starttime > pcurr OR
			(starttime = pcurr) AND (id > pid)) ORDER BY starttime DESC, id  DESC;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION NextPrevLocation (pid int, OUT pprevid int, OUT pnextid int) AS $$
BEGIN
	SELECT	 max(id)
	FROM	locations INTO pprevid
	WHERE	id < pid;

	SELECT	min(id)
	FROM	locations INTO pnextid
	WHERE	id > pid;
	RETURN;
END;
$$ LANGUAGE plpgsql;


CREATE TYPE AlbumList AS (
       albumid integer,
       title varchar(50),
       private boolean,
       DisplayImage integer,
       ImageCount bigint
);

CREATE FUNCTION PagedAlbumList (pownerID text) RETURNS SETOF AlbumList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedAlbumList (pownerID, 1, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedAlbumList (pownerID text, ppageNum int) RETURNS SETOF AlbumList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedAlbumList (pownerID, ppageNum, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedAlbumList (pownerID text, ppageNum int, ppageSize int) RETURNS SETOF AlbumList AS $$
DECLARE 
	prows int;
	pkeyid int;
	r RECORD;
BEGIN
	IF ppageNum = 1 THEN
		pkeyid := 0;
	ELSE
		/* get the values for the date and row */
		prows := (ppageNum-1) * ppageSize;
		SELECT albumid FROM albums INTO pkeyid
		  WHERE (Albums.private = FALSE) OR (Albums.private = TRUE) AND (Albums.ownerid = pownerid)
		  ORDER BY albumid ASC OFFSET prows LIMIT 1;
	END IF;

	FOR r IN SELECT Albums.albumid, Albums.title, Albums.private, MIN(images.id) AS DisplayImage, count(images.id) as ImageCount 
	FROM Albums LEFT OUTER JOIN images ON Albums.albumid = images.album 
	WHERE ((Albums.private = FALSE) OR (Albums.private = TRUE) AND (Albums.ownerid = pownerid)) AND (albums.albumid > pkeyid)
	GROUP BY  albumid, albums.title, albums.private LIMIT ppageSize LOOP
	      RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;


CREATE TYPE AnnouncementList AS (
       id integer,
       itemdate timestamptz,
       title varchar (500),
       description varchar (500),
       photo integer
);

CREATE FUNCTION PagedAnnouncementList () RETURNS SETOF AnnouncementList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedAnnouncementList (1, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedAnnouncementList (ppageNum int) RETURNS SETOF AnnouncementList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedAnnouncementList (ppageNum, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;


CREATE FUNCTION PagedAnnouncementList (ppageNum int, ppageSize int) RETURNS SETOF AnnouncementList AS $$
DECLARE 
	prows int;
	pkeydate timestamptz;
	pkeyid int;
	r RECORD;
BEGIN
	IF ppageNum = 1 THEN
		pkeydate := to_timestamp(0);
		pkeyid := 0;
	ELSE
			/* get the values for the date and row */
		prows := (ppageNum-1) * ppageSize;
		SELECT itemdate, id FROM Announcements INTO pkeydate,pkeyid ORDER BY itemdate ASC, id ASC OFFSET prows LIMIT 1; 
	END IF;

	FOR r IN SELECT id, itemdate, title, description, photo FROM Announcements 
	WHERE (itemdate > pkeydate OR
			(itemdate = pkeydate) AND (id > pkeyid))
	ORDER BY itemdate ASC, id ASC LIMIT ppageSize LOOP
	      RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE TYPE LocationList AS (
	id integer,
	title varchar (500),
	description varchar (800),
	linkURL varchar (500),
	address varchar (300),
	photo integer,
	directions varchar (800) 
);

CREATE FUNCTION PagedLocationsList () RETURNS SETOF LocationList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedLocationsList (1, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedLocationsList (ppageNum int) RETURNS SETOF LocationList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedLocationsList (ppageNum, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedLocationsList (ppageNum int, ppageSize int) RETURNS SETOF LocationList AS $$
DECLARE 
	prows int;
	pkeyid int;
	r RECORD;
BEGIN
	IF ppageNum = 1 THEN
		pkeyid := 0;
	ELSE
			/* get the values for the date and row */
		prows := (ppageNum-1) * ppageSize;
		SELECT id FROM locations INTO pkeyid ORDER BY id ASC OFFSET prows LIMIT 1;
	END IF;

	FOR r IN SELECT id, title, description, linkURL, address, photo, directions
		FROM Locations WHERE id > pkeyid ORDER BY id ASC LIMIT ppageSize LOOP
	      RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE TYPE EventList AS (
       id integer,
       starttime timestamptz,
       title varchar (500),
       description varchar (500),
       photo integer,
       locationname varchar (500)
);

CREATE FUNCTION PagedRecentEventList () RETURNS SETOF EventList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedRecentEventList (1, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedRecentEventList (ppageNum int) RETURNS SETOF EventList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedRecentEventList (ppageNum, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedRecentEventList (ppageNum int, ppageSize int) RETURNS SETOF EventList AS $$
DECLARE
	r RECORD;
	prows int;
	pkeydate timestamptz;
	pkeyid int;
BEGIN	
	IF ppageNum = 1 THEN
		pkeydate := NOW();
		pkeyid := 0;
	ELSE
		/* get the values for the date and row */
		prows := (ppageNum-1) * ppageSize;
		SELECT starttime, id FROM Events INTO pkeydate, pkeyid
				WHERE starttime < NOW()
				ORDER BY starttime DESC, id DESC OFFSET prows LIMIT 1;
	END IF;

	FOR r IN SELECT Events.id, Events.starttime, Events.title, Events.description, Events.photo, 
		Locations.title AS locationname 
	FROM Events LEFT OUTER JOIN Locations ON Events.location = Locations.id 
	WHERE (Events.starttime < pkeydate OR
			(Events.starttime = pkeydate) AND (events.id < pkeyid))
	ORDER BY Events.starttime DESC, Events.id DESC LIMIT ppageSize LOOP
	      RETURN NEXT r;
	END LOOP; 
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedUpcommingEventList () RETURNS SETOF EventList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedUpcommingEventList (1, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedUpcommingEventList (ppageNum int) RETURNS SETOF EventList AS $$
DECLARE
	r RECORD;
BEGIN
	FOR r IN SELECT * FROM PagedUpcommingEventList (ppageNum, 10) LOOP
	    RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PagedUpcommingEventList (ppageNum int, ppageSize int) RETURNS SETOF EventList AS $$
DECLARE 
	prows int;
	pkeydate timestamptz;
	pkeyid int;
	r RECORD;
BEGIN
	IF ppageNum = 1 THEN
		pkeydate := NOW();
		pkeyid := 0;
	ELSE
		/* get the values for the date and row */
		prows := (ppageNum-1) * ppageSize;
		SELECT starttime, id FROM Events INTO pkeydate, pkeyid
			WHERE Events.starttime > NOW()
			ORDER BY starttime ASC, id ASC OFFSET prows LIMIT 1;  
	END IF;

	FOR r IN SELECT Events.id, Events.starttime, Events.title, Events.description, Events.photo, 
		Locations.title AS locationname 
	FROM Events LEFT OUTER JOIN Locations ON Events.location = Locations.id 
	WHERE (Events.starttime > pkeydate OR
			(Events.starttime = pkeydate) AND (events.id > pkeyid))
	ORDER BY Events.starttime ASC, Events.id ASC LIMIT ppageSize LOOP
	      RETURN NEXT r;
	END LOOP;
	RETURN;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION PrevAnnouncement (pid int) RETURNS bigint AS $$
DECLARE 
	pcurr timestamptz;
	previd bigint;
BEGIN
	SELECT itemdate FROM Announcements INTO pcurr WHERE (id = pid);

	SELECT id FROM Announcements INTO previd
	WHERE	(itemdate < pcurr OR
			(itemdate = pcurr) AND (id < pid)) ORDER BY itemdate DESC, id DESC LIMIT 1;
	RETURN previd;
END;
$$ LANGUAGE plpgsql;



-- alter object owners
ALTER TABLE Users OWNER TO test;
ALTER INDEX users_email_index OWNER TO test;
ALTER INDEX users_islockedout_index OWNER TO test;
ALTER TABLE Roles OWNER TO test;
ALTER TABLE UsersInRoles OWNER TO test;
ALTER TABLE Profiles OWNER TO test;
ALTER INDEX profiles_isanonymous_index OWNER TO test;
ALTER TABLE ProfileData OWNER TO test;
ALTER TABLE Albums OWNER TO test;
ALTER TABLE Announcements OWNER TO test;
ALTER TABLE Events OWNER TO test;
ALTER TABLE Locations OWNER TO test;
ALTER TABLE MemberInfo OWNER TO test;
ALTER TABLE images OWNER TO test;
ALTER FUNCTION AlbumList (puserid text) OWNER TO test;
ALTER TYPE ResultsTemp OWNER TO test;
ALTER FUNCTION MemberCountByLetter() OWNER TO test;
ALTER FUNCTION NextAnnouncement (pid int) OWNER TO test;
ALTER FUNCTION NextPrevAnnouncement (pid int, OUT pprevid int, OUT pnextid int) OWNER TO test;
ALTER FUNCTION NextPrevEvent (pid int,	OUT pprevid int, OUT pnextid int) OWNER TO test;
ALTER FUNCTION NextPrevLocation (pid int, OUT pprevid int, OUT pnextid int) OWNER TO test;
ALTER TYPE AlbumList OWNER TO test;
ALTER FUNCTION PagedAlbumList (pownerID text) OWNER TO test;
ALTER FUNCTION PagedAlbumList (pownerID text, ppageNum int) OWNER TO test;
ALTER FUNCTION PagedAlbumList (pownerID text, ppageNum int, ppageSize int) OWNER TO test;
ALTER TYPE AnnouncementList OWNER TO test;
ALTER FUNCTION PagedAnnouncementList () OWNER TO test;
ALTER FUNCTION PagedAnnouncementList (ppageNum int) OWNER TO test;
ALTER FUNCTION PagedAnnouncementList (ppageNum int, ppageSize int) OWNER TO test;
ALTER FUNCTION PagedLocationsList () OWNER TO test;
ALTER FUNCTION PagedLocationsList (ppageNum int) OWNER TO test;
ALTER FUNCTION PagedLocationsList (ppageNum int, ppageSize int) OWNER TO test;
ALTER FUNCTION PagedRecentEventList () OWNER TO test;
ALTER FUNCTION PagedRecentEventList (ppageNum int) OWNER TO test;
ALTER FUNCTION PagedRecentEventList (ppageNum int, ppageSize int) OWNER TO test;
ALTER FUNCTION PagedUpcommingEventList () OWNER TO test;
ALTER FUNCTION PagedUpcommingEventList (ppageNum int) OWNER TO test;
ALTER FUNCTION PagedUpcommingEventList (ppageNum int, ppageSize int) OWNER TO test;
ALTER FUNCTION PrevAnnouncement (pid int) OWNER TO test;

-- test user data
INSERT INTO memberinfo (address, phone, firstname, lastname, avatar, memberid) VALUES ('Address', '123456', 'Test', 'User', '\\377\\330\\377\\340\\000\\020JFIF\\000\\001\\001\\000\\000\\001\\000\\001\\000\\000\\377\\333\\000C\\000\\010\\006\\006\\007\\006\\005\\010\\007\\007\\007\\011\\011\\010\\012\\014\\024\\015\\014\\013\\013\\014\\031\\022\\023\\017\\024\\035\\032\\037\\036\\035\\032\\034\\034 $.'' ",#\\034\\034(7),01444\\037''9=82<.342\\377\\333\\000C\\001\\011\\011\\011\\014\\013\\014\\030\\015\\015\\0302!\\034!22222222222222222222222222222222222222222222222222\\377\\300\\000\\021\\010\\000E\\000E\\003\\001"\\000\\002\\021\\001\\003\\021\\001\\377\\304\\000\\037\\000\\000\\001\\005\\001\\001\\001\\001\\001\\001\\000\\000\\000\\000\\000\\000\\000\\000\\001\\002\\003\\004\\005\\006\\007\\010\\011\\012\\013\\377\\304\\000\\265\\020\\000\\002\\001\\003\\003\\002\\004\\003\\005\\005\\004\\004\\000\\000\\001}\\001\\002\\003\\000\\004\\021\\005\\022!1A\\006\\023Qa\\007"q\\0242\\201\\221\\241\\010#B\\261\\301\\025R\\321\\360$3br\\202\\011\\012\\026\\027\\030\\031\\032%&''()*456789:CDEFGHIJSTUVWXYZcdefghijstuvwxyz\\203\\204\\205\\206\\207\\210\\211\\212\\222\\223\\224\\225\\226\\227\\230\\231\\232\\242\\243\\244\\245\\246\\247\\250\\251\\252\\262\\263\\264\\265\\266\\267\\270\\271\\272\\302\\303\\304\\305\\306\\307\\310\\311\\312\\322\\323\\324\\325\\326\\327\\330\\331\\332\\341\\342\\343\\344\\345\\346\\347\\350\\351\\352\\361\\362\\363\\364\\365\\366\\367\\370\\371\\372\\377\\304\\000\\037\\001\\000\\003\\001\\001\\001\\001\\001\\001\\001\\001\\001\\000\\000\\000\\000\\000\\000\\001\\002\\003\\004\\005\\006\\007\\010\\011\\012\\013\\377\\304\\000\\265\\021\\000\\002\\001\\002\\004\\004\\003\\004\\007\\005\\004\\004\\000\\001\\002w\\000\\001\\002\\003\\021\\004\\005!1\\006\\022AQ\\007aq\\023"2\\201\\010\\024B\\221\\241\\261\\301\\011#3R\\360\\025br\\321\\012\\026$4\\341%\\361\\027\\030\\031\\032&''()*56789:CDEFGHIJSTUVWXYZcdefghijstuvwxyz\\202\\203\\204\\205\\206\\207\\210\\211\\212\\222\\223\\224\\225\\226\\227\\230\\231\\232\\242\\243\\244\\245\\246\\247\\250\\251\\252\\262\\263\\264\\265\\266\\267\\270\\271\\272\\302\\303\\304\\305\\306\\307\\310\\311\\312\\322\\323\\324\\325\\326\\327\\330\\331\\332\\342\\343\\344\\345\\346\\347\\350\\351\\352\\362\\363\\364\\365\\366\\367\\370\\371\\372\\377\\332\\000\\014\\003\\001\\000\\002\\021\\003\\021\\000?\\000\\364\\25529\\374c\\250j\\227W\\327\\367\\220\\330\\331^\\311gogg;\\300\\016\\314fI\\031\\010fbO\\003;@\\354O5;i^\\026Gemn\\3602\\234\\020u\\333\\216\\017\\375\\375\\252\\236\\015$h^) \\340\\215V\\367\\221\\364\\025\\037\\205\\265\\030\\233@\\260\\212\\025\\005\\231p\\025{\\234\\320\\005\\357\\354\\317\\012\\377\\000\\320n\\357\\377\\000\\007\\267\\037\\374v\\223\\3733\\302\\377\\000\\364\\033\\273\\377\\000\\301\\355\\307\\377\\000\\035\\255\\357\\261\\334`a\\243\\374\\317\\370S\\305\\221\\316\\031\\317\\324(\\307\\363\\240\\016w\\3733\\303\\037\\364\\032\\273\\377\\000\\301\\355\\307\\377\\000\\035\\244\\376\\314\\360\\317\\375\\006n\\377\\000\\360{q\\377\\000\\307k\\2446''\\264\\277\\232\\325ymncB\\312\\021\\300\\354\\0174\\300\\302:o\\206\\377\\000\\3501w\\377\\000\\203\\313\\217\\376;R''\\207\\264\\233\\310\\031\\254\\265MS \\340M\\006\\261;\\224o\\305\\310\\317\\261\\007\\351R\\377\\000jG\\352*\\227\\207\\345\\216o\\025k\\262F\\241A\\212\\3338\\030\\311\\001\\371\\376tX\\015\\037\\010\\352\\327\\227\\220\\352VZ\\204\\302\\342\\347M\\274kSr\\024/\\2340\\031X\\250\\340\\0340\\004\\0162(\\252^\\015\\377\\000\\220\\267\\212\\377\\000\\354+\\377\\000\\264c\\242\\220\\025\\374!\\377\\000 \\037\\025\\177\\330V\\367\\371\\012\\340\\374\\014\\336 m6\\312k=6\\346F\\205\\211Vx\\210C\\203\\320\\223\\201\\372\\327\\242x\\000\\342\\327^\\377\\000\\260\\335\\327\\363Z\\353\\363@\\024\\354\\357\\245\\222\\335\\032\\372\\316K9H\\033\\225\\310e\\007\\037\\336RF;s\\212\\273\\270\\020\\0109\\007\\275&i\\245\\250\\001KS\\026ds\\204\\221X\\377\\000\\262A\\240\\265W\\272\\267\\267\\273\\217\\313\\270\\205%Q\\320:\\203\\217\\247\\245\\000y\\307\\210\\256Z\\303_\\273\\2018P\\373\\200\\364\\310\\317\\365\\251\\376\\036\\\\\\033\\215[]\\2239\\310\\207\\007\\376\\373\\256\\037[K\\233mZ\\356\\316y]\\2142\\262d\\236\\240\\036>\\274b\\272\\377\\000\\205\\274K\\253\\177\\273\\017\\376\\317[J6\\2117\\324\\351|\\033\\377\\000!o\\025\\377\\000\\330W\\377\\000h\\307E\\036\\014\\377\\000\\220\\257\\212\\377\\000\\354+\\377\\000\\264c\\242\\261(O\\001\\034[k\\337\\366\\033\\272\\376k]nk\\220\\360!\\305\\266\\275\\377\\000a\\273\\257\\346\\265\\325<\\251\\034m$\\216\\021\\024e\\231\\216\\000\\024\\000\\351%H\\220\\274\\216\\250\\213\\311f8\\003\\361\\245\\335\\221\\232\\362\\257\\026x\\232MnSij\\305,P\\3762\\237S\\355\\355Y\\032n\\253\\251\\3518\\026W\\222\\304\\231\\317\\227\\234\\241\\377\\000\\200\\236*\\324.\\205s\\332%E\\2266G\\004\\253\\014\\034\\022\\017\\346:VCjo\\245H \\324\\311\\020\\023\\210\\257\\177\\200\\216\\302O\\356\\267l\\364=x\\316\\0077\\247\\374@\\224mMF\\3147\\254\\220\\034\\037\\373\\344\\377\\000\\215l^x\\267L:L\\323\\333\\\\+\\313\\267\\013\\023\\0141''\\247\\007\\265\\034\\215i`\\271\\346\\276/e\\237\\305z\\204\\221\\020\\313\\274\\014\\217e\\002\\272/\\206@\\254\\272\\266\\177\\273\\017\\376\\324\\256P\\303\\271\\211 d\\234\\3600+\\261\\370|\\276\\\\\\272\\247\\270\\207\\377\\000g\\255\\346\\255\\013\\020\\2677\\274\\027\\377\\000!O\\025\\177\\330W\\377\\000h\\307E\\036\\012\\377\\000\\220\\237\\212\\177\\354)\\377\\000\\264c\\242\\271M\\010\\274\\016qo\\256\\377\\000\\330j\\353\\371\\2553\\304\\376"\\360\\266g\\3235\\215s\\354\\257\\006\\326\\232\\004fV;\\206G\\000\\022\\336\\270\\031\\307zO\\006\\022\\261k\\252x#Z\\272\\310\\364\\345j\\246\\217\\243\\334E\\361[^\\325.\\2551eqg\\024QL\\300\\020\\331\\331\\270\\017\\373\\344\\347\\377\\000\\256)\\201\\224&\\370s\\346\\333\\3045\\365-p3\\036&$\\177\\300\\2160\\207\\331\\261Wu\\273\\037\\005xrD\\217V\\324\\336\\326W\\033\\2266\\221\\231\\310\\311\\031\\332\\240\\234d\\021\\234c\\203\\\\\\227\\374"Z\\327\\374)\\217\\354\\257\\354\\311?\\264\\015\\377\\000\\235\\344q\\273\\033\\266\\347\\257\\371\\034\\364\\256\\252\\356\\333S\\360\\367\\304M_\\304)\\244K\\252\\331j\\021$i%\\253)\\232\\002\\240\\015\\273X\\214\\251\\333\\324q\\323\\351O\\231\\205\\221$\\226>\\013\\217GM]\\265C\\375\\236\\356#Y\\304\\304\\256\\342p\\007\\003 \\372\\347\\247|T:t>\\010\\325\\365\\027\\323\\364\\375[\\355\\027K\\223\\345\\244\\255\\363c\\256\\322F\\033\\360&\\271}C\\301\\232\\374\\276\\007\\326\\025l<\\273\\255KW[\\310\\364\\350\\245R-\\343%\\207\\\\\\343?8\\316:\\005\\004\\343\\007\\035\\216\\265\\244\\\\\\311\\361#\\303w\\326\\226\\270\\260\\264\\206\\3467\\222<\\005\\210yl\\024c\\260\\344\\001G4\\273\\212\\310\\317\\275\\223\\300z~\\240\\326\\027Z\\322\\307r\\254Q\\223\\315b\\021\\201\\301\\014\\300\\020\\244\\036\\271#\\025\\321\\351\\021Xi\\363Ikcit\\026EY\\015\\333\\000\\321\\3121\\221\\207\\014s\\303z\\016\\246\\270\\213=?Z\\320|+\\252\\370X\\370vK\\331\\257^o"\\356\\031#\\362\\245\\3360\\036B\\304\\025#\\031\\031\\364\\035:\\327g\\341\\255:}\\023\\303\\032v\\231s0\\232{hv;\\203\\306rN\\007\\260\\316\\321\\354(rop\\262,x''\\376B>(\\377\\000\\260\\247\\376\\321\\216\\212O\\003\\020\\327\\376( \\347\\376&\\230\\374D1\\203EH\\315\\035K\\302\\212\\372\\214\\372\\216\\233\\252^iw\\027\\0303\\213q\\033\\244\\254\\006\\003\\024ua\\273\\034dc=\\352\\237\\374#\\232\\307\\375\\015\\327\\377\\000\\370\\011k\\377\\000\\306\\250\\242\\200\\017\\370G5\\217\\372\\033\\257\\377\\000\\360\\022\\327\\377\\000\\215Q\\377\\000\\010\\336\\261\\377\\000Cu\\377\\000\\376\\002Z\\377\\000\\361\\252(\\240\\004\\377\\000\\204kW\\377\\000\\241\\272\\377\\000\\377\\000\\001-\\177\\370\\325\\037\\360\\214\\352\\377\\000\\3646\\337\\377\\000\\340%\\257\\377\\000\\033\\242\\212\\000O\\370F5o\\372\\033o\\377\\000\\360\\022\\327\\377\\000\\215\\323[\\302Z\\234\\240\\243\\370\\263Q\\332x;-\\355\\324\\376\\004G\\221\\370QE\\000tz\\036\\205e\\341\\3755,\\254\\221\\204`\\226fs\\271\\235\\211\\311bORM\\024Q@\\037\\377\\331', '34cfab57-1cbc-4849-ae13-59134aae25d7');

INSERT INTO roles (rolename, applicationname) VALUES ('Administrators', '/');
INSERT INTO roles (rolename, applicationname) VALUES ('Guests', '/');

INSERT INTO users (pid, username, applicationname, email, "comment", "password", passwordquestion, passwordanswer, isapproved, lastactivitydate, lastlogindate, lastpasswordchangeddate, creationdate, isonline, islockedout, lastlockedoutdate, failedpasswordattemptcount, failedpasswordattemptwindowstart, failedpasswordanswerattemptcount, failedpasswordanswerattemptwindowstart) VALUES ('34cfab57-1cbc-4849-ae13-59134aae25d7', 'test', '/', 'test@example.com', '', 'YX6V08gSdP+RYgRtaVePad6wdVw=', 'question', 'dnc4cGDJy7KCmNn7vJJHG5OCbdU=', true, '2007-06-13 13:30:37.76176+02', NULL, '2007-06-13 13:30:37.76176+02', '2007-06-13 13:30:37.76176+02', NULL, false, '2007-06-13 13:30:37.76176+02', 0, '2007-06-13 13:30:37.76176+02', 0, '2007-06-13 13:30:37.76176+02');

INSERT INTO usersinroles (username, rolename, applicationname) VALUES ('test', 'Administrators', '/');
INSERT INTO Albums (title, parentid, private, description, ownerid) VALUES ('My Album', 0, FALSE, '', '34cfab57-1cbc-4849-ae13-59134aae25d7');

